package com.weaver.seconddev.cpic.dao;

import com.weaver.ebuilder.datasource.api.entity.SqlParamEntity;
import com.weaver.seconddev.cpic.util.DatabaseUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Component
public class EmployeeImportTxtDao {

    private final static Logger log = LoggerFactory.getLogger(EmployeeImportTxtDao.class);

    @Autowired
    private DatabaseUtils databaseUtils;

    public Map<String,Object> queryMainDataByFormDataId(String tenant_key,String form_data_id){
        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";
        Map<String,Object> recordMap = new HashMap<String,Object>();
        try{
            String dataSql =" select drwj " +
                            " from uf_employee_exp " +
                            " where form_data_id = ?\n" +
                            " and tenant_key=?\n" +
                            " and delete_type=0 \n" ;

            log.error("queryMainDataByFormDataId--dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(form_data_id);
            paramList.add(tenant_key);
            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("queryMainDataByFormDataId-recordList:"+recordList.size());
            if(recordList.size()>0){
                recordMap = recordList.get(0);
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("queryMainDataByFormDataId-e:" + e);
        }
        return recordMap;
    }

    /***
     *
     * @param tenant_key
     * @return
     */
    public Map<String,Map<String,String>> getHrmDepartmentCode(String tenant_key){
        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";
        Map<String,Map<String,String>> dataMap = new HashMap<String,Map<String,String>>();
        try{
            String dataSql =" select p.description,d.id as departmentid,d.code as departmentcode,d.name as departmentname,p.code as  positioncod,p.name as positionname,p.id as positionid\n" +
                            " from eteams.department d\n" +
                            " inner join eteams.position p on p.DEPARTMENT = d.id\n" ;

            log.error("dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
//            paramList.add(tenant_key);
            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("recordList:"+recordList.size());
            for(int i=0;i<recordList.size();i++){
                Map<String,Object> recordMap  = recordList.get(i);
                String description = String.valueOf(recordMap.get("description"));
                String departmentid = String.valueOf(recordMap.get("departmentid"));
                String positionid = String.valueOf(recordMap.get("positionid"));
                if(StringUtils.isNotBlank(description)){
                    Map<String,String> postMap = new HashMap<String,String>();
                    postMap.put("departmentid",departmentid);
                    postMap.put("positionid",positionid);
                    dataMap.put(description,postMap);
                }
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("queryMainDataByFormDataId-e:" + e);
        }
        return dataMap;
    }

    public Map<String,Object> getHrDictionarySetting(String tenant_key,String type){
        String groupId = "weaver-hr-service";
        String sourceType = "LOGIC";
        Map<String,Object> dataMap = new HashMap<String,Object>();
        try{
            String dataSql ="select code,name,id from hr_dictionary_setting where type=? " ;
            log.error("dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(type);
            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("recordList:"+recordList.size());
            for(int i=0;i<recordList.size();i++){
                Map<String,Object> recordMap  = recordList.get(i);
                String code = String.valueOf(recordMap.get("code"));
                String id = String.valueOf(recordMap.get("id"));
                if(StringUtils.isNotBlank(code)){
                    dataMap.put(code,id);
                }
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("e:" + e);
        }
        return dataMap;
    }


    public Map<String,Object> queryEmployeeByNationalId(String tenant_key,String nationalid){
        String groupId = "weaver-hr-service";
        String sourceType = "LOGIC";
        Map<String,Object> recordMap = new HashMap<String,Object>();
        try{
            String dataSql =" select h.id \n" +
                            " from hr_userinfo k \n" +
                            " inner join eteams.employee h on h.id = k.user\n" +
                            " where k.id_no = ? \n" ;

            log.error("dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(nationalid);
//            paramList.add(tenant_key);
            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("recordList:"+recordList.size());
            if(recordList.size()>0){
                recordMap = recordList.get(0);
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("e:" + e);
        }
        return recordMap;
    }

    /**
     *
     * @param tenant_key
     * @return
     */
    public Map<String,String> queryPropDataByDl(String tenant_key,String dl){
        String groupId = "weaver-hr-service";
        String sourceType = "LOGIC";
        Map<String,String> dataMap = new HashMap<String,String>();
        try{
            String dataSql =" select pkey,pvalue from uf_prop where dl = ? "  ;
            log.error("dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(dl);
            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("recordList:"+recordList.size());
            for(int i=0;i<recordList.size();i++){
                Map<String,Object> recordMap  = recordList.get(i);
                String pkey = String.valueOf(recordMap.get("pkey"));
                String pvalue = String.valueOf(recordMap.get("pvalue"));
                if(StringUtils.isNotBlank(pkey)){
                    dataMap.put(pkey,pvalue);
                }
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("e:" + e);
        }
        return dataMap;
    }


    /***
     *
     * @param tenant_key
     * @param form_data_id
     * @return
     */
    public Map<String,Object> updateEmployeeImpResult(String tenant_key,String form_data_id,String drsl,String xzsl,String gxsl,String sbsl){
        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";
        Map<String, Object> result = new HashMap<String,Object>();
        try{
            String dataSql =" update  uf_employee_exp set drsl = ?,xzsl = ?,gxsl = ?,sbsl = ?" +
                            " where form_data_id = ?\n" +
                            " and tenant_key=?\n" +
                            " and delete_type=0 \n" ;

            log.error("queryMainDataByFormDataId--dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);

            paramList.add(drsl);
            paramList.add(xzsl);
            paramList.add(gxsl);
            paramList.add(sbsl);
            paramList.add(form_data_id);
            paramList.add(tenant_key);
            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);

        }catch (Exception e){
            e.printStackTrace();
            log.error("queryMainDataByFormDataId-e:" + e);
        }
        return result;
    }



    /**
     *
     * @param tenant_key
     * @param formName
     * @param dataKey
     * @return
     */
    public Map<String, Object> queryFromTableField(String tenant_key,String formName,String dataKey){
        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";
        Map<String, Object> fieldMap = new HashMap<String, Object>();
        try{
            // 'dcsl','sfdccg','dcr','dcrq','dcsj'
            String dataSql =" select id,form_id,title,data_key " +
                    " from form_field " +
                    " where form_id in(select form_id from form_table where table_name=? and delete_type=0 and tenant_key=?) \n" +
                    " and data_key in("+dataKey+")\n" +
                    " and sub_form_id is null " +
                    " and tenant_key=? \n" +
                    " and delete_type=0" ;

            log.error("queryFromTableField--dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(formName);
            paramList.add(tenant_key);
            paramList.add(tenant_key);

            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("queryFromTableField:"+recordList.size());
            for(Map<String,Object> recordMap : recordList ) {
                String data_key = String.valueOf(recordMap.get("data_key"));
                String id = String.valueOf(recordMap.get("id"));
                fieldMap.put(data_key,id);
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("queryFromTableField:e:" + e);
        }
        return fieldMap;
    }


    public Map<String, Object> queryFieldOptionByFieldid(String tenant_key,String fieldId){
        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";
        Map<String, Object> optionMap = new HashMap<String, Object>();
        try{

            String dataSql ="  select name,value_key from field_option where field_id=? " +
                            " and tenant_key=? \n" +
                            " and delete_type=0" ;

            log.error("dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(fieldId);
            paramList.add(tenant_key);

            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("queryFromTableField:"+recordList.size());
            for(Map<String,Object> recordMap : recordList ) {
                String name = String.valueOf(recordMap.get("name"));
                String value_key = String.valueOf(recordMap.get("value_key"));
                optionMap.put(value_key,name);
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("queryFromTableField:e:" + e);
        }
        return optionMap;
    }

}
