package com.weaver.seconddev.prod.dao;

import com.weaver.ebuilder.datasource.api.entity.SqlParamEntity;
import com.weaver.seconddev.prod.util.DatabaseUtils;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.text.SimpleDateFormat;
import java.util.*;


/***
 * author:shil
 * date:2025/03/05
 */
@Component
public class EmployeeExportTxtDao {

    private final static Logger log = LoggerFactory.getLogger(EmployeeExportTxtDao.class);

    @Autowired
    private DatabaseUtils databaseUtils;

    /***
     *
     * @param tenant_key
     * @param form_data_id
     * @return
     */
    public Map<String,Object> queryIncDate(String tenant_key,String form_data_id){
        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";
        Map<String,Object> recordMap = new HashMap<String,Object>();
        try{
            String dataSql =" select concat(dcrq,' ',dcsj) as dcsj " +
                    " from uf_employee_imp " +
                    " where dcr = ? and sfdccg = '0' \n" +
                    " and tenant_key=?\n" +
                    " and delete_type=0 \n" ;

            log.error("queryMainDataByFormDataId--dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(form_data_id);
            paramList.add(tenant_key);
            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("queryMainDataByFormDataId-recordList:"+recordList.size());
            if(recordList.size()>0){
                recordMap = recordList.get(0);
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("queryMainDataByFormDataId-e:" + e);
        }
        return recordMap;
    }


    /***
     *
     * @param tenant_key
     * @return
     */
    public Map<String,Object> queryCompanyData(String tenant_key){
        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";

        Map<String, Object> recordMap = new HashMap<String,Object>();
        try{
            String dataSql =" select code as COMPANY,name as DESCR\n" +
                    " from eteams.department\n" +
                    " where parent is null\n" +
                    " and type='subcompany'\n" +
                    " and delete_type=0 " +
                    " and tenant_key= ? "+
                    " and status = 1 " ;

            log.error("queryDt1DataByFormDataId--dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(tenant_key);

            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("recordList:"+recordList.size());
            if(recordList.size() >0){
                recordMap = recordList.get(0);
            }

        }catch (Exception e){
            e.printStackTrace();
            log.error("e:" + e);
        }
        return recordMap;
    }

    /**
     *
     * @param tenant_key
     * @return
     */
    public List<Map<String, Object>> queryEmployeeBaseList(String tenant_key,String type){
        String groupId = "weaver-hr-service";
        String sourceType = "LOGIC";
        List<Map<String, Object>> recordList = new ArrayList<Map<String, Object>>();
        try{


            Map<String,String> sequenceCodeMap = queryHrmSequenceCode(tenant_key);
            Map<String,String> sequenceMarkMap = queryHrmSequenceReamrk(tenant_key);

            Map<String,Object> companyMap = queryCompanyData(tenant_key);

            String lastExpDate = queryMaxDateByExport(tenant_key);
            log.error("lastExpDate:"+lastExpDate);

            String where = "" ;
            if("1".equals(type)){

                where = " and k.id in(" +
                        "   select id from eteams.employee t1 where ( \n" +
                        "   (to_char(t1.update_time,'yyyy-mm-dd hh24:mi:ss') > '"+lastExpDate+"' and t1.update_time is not null )\n" +
                        "       or \n" +
                        "       t1.formdata in( select t3.form_data_id from eteams.ft_1104523695920578614 t3 where to_char(t3.update_time,'yyyy-mm-dd hh24:mi:ss') > '"+lastExpDate+"' and t3.update_time is not null )\n" +
                        "   ) \n" +
                        "   union all \n" +
                        "   select \"USER\" from hr_userinfo t4 where (\n" +
                        "   (to_char(t4.update_time,'yyyy-mm-dd hh24:mi:ss') > '"+lastExpDate+"' and t4.update_time is not null)\n" +
                        "       or\n" +
                        "       t4.form_data in(select t2.form_data_id from ft_1104525443890176000 t2 where to_char(t2.update_time,'yyyy-mm-dd hh24:mi:ss') > '"+lastExpDate+"' and t2.update_time is not null )\n" +
                        "   ) " +
                        " )";
                log.error("where:"+where);
            }

            String dataSql =" select k.id as EMPLID,\n" +
                    "     '1' as EMPL_RCD,\n" +
                    "     k.job_num as DC_EMPL_NO,\n" +
                    "     k.personnel_status as DC_EMPL_STATUS,\n" +
                    "     '1' as DC_HR_STATUS,\n" +
                    "     p.code as POSITION_NBR,\n" +
                    "     p.name as DC_DESCR50,\n" +
                    "     d.code as DEPTID,\n" +
                    "     d.name as DC_DESCR50_2,\n" +
                    "     to_char(k.hiredate,'yyyy-mm-dd') as DC_CO_ENTRY_DT,\n" +
                    "     '' as TERMINATION_DT,\n" +
                    "     f.nwq as DC_BZGW_NWSERV,\n" +
                    "     ft.rzdqbmrq as DEPT_ENTRY_DT,\n" +
                    "     ft.rdqgwrq as POSITION_ENTRY_DT,\n" +
                    "     ft.yglx as EMPL_CLASS,\n" +
                    "     ft.ygzj as DC_GRADE_CD,\n" +
                    "     ft.xlms  as JOB_FUNCTION,\n" +
                    "     ft.zxms as DC_DISCRIPTION,\n" +
                    "     to_char(k.active_date,'yyyy-mm-dd') as EFFDT\n" +
                    "     from eteams.employee k\n" +
                    "     left join (select * from eteams.department where type='department' ) d on d.id = k.department\n" +
                    "     left join eteams.position p on p.id = k.position\n" +
                    "     left join eteams.ft_1104523695920578614 f on f.form_data_id = k.formdata\n" +
                    "     left join hr_userinfo h2 on h2.\"USER\" = k.id\n" +
                    "     left join ft_1104525443890176000 ft on ft.form_data_id = h2.form_data\n" +
                    "     where k.personnel_status = 3 \n" +
                    "     and k.delete_type=0 " + where +
                    "     and k.tenant_key= ? ";

            log.error("queryEmployeeBaseList--dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(tenant_key);

            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            recordList = databaseUtils.getDataSourceList(result);
            for(int i=0;i<recordList.size();i++){
                Map<String, Object> recordMap = recordList.get(i);
                recordMap.putAll(companyMap);

                String jobFunction = String.valueOf(recordMap.get("job_function"));
                log.error("jobFunction:"+jobFunction);

                if(StringUtils.isNotBlank(jobFunction)){
                    if(sequenceMarkMap.containsKey(jobFunction)){
                        String xlms = sequenceMarkMap.get(jobFunction);
                        log.error("xlms:"+xlms);
                        recordMap.put("descrshort",xlms);
                    }else{
                        recordMap.put("descrshort","");
                    }
                    if(sequenceCodeMap.containsKey(jobFunction)){
                        String xl = sequenceCodeMap.get(jobFunction);
                        log.error("xl:"+xl);
                        recordMap.put("job_function",xl);
                    }
                }else{
                    recordMap.put("descrshort","");
                }
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("queryFromTableField:e:" + e);
        }
        return recordList;
    }

    public List<Map<String, Object>> queryEmployeeExtraList(String tenant_key){
        String groupId = "weaver-hr-service";
        String sourceType = "LOGIC";
        List<Map<String, Object>> recordList = new ArrayList<Map<String, Object>>();
        try{

            Map<String,String> sequenceCodeMap = queryHrmSequenceCode(tenant_key);
            Map<String,String> sequenceMarkMap = queryHrmSequenceReamrk(tenant_key);

            Map<String,Object> companyMap = queryCompanyData(tenant_key);

            String lastExpDate = queryMaxDateByExport(tenant_key);
            log.error("lastExpDate:"+lastExpDate);


            String dataSql =" select k.id as EMPLID,\n" +
                    "       '1' as EMPL_RCD,\n" +
                    "       k2.job_num as DC_EMPL_NO,\n" +
                    "       k2.personnel_status as DC_EMPL_STATUS,\n" +
                    "       '1' as DC_HR_STATUS,\n" +
                    "       p.code as POSITION_NBR,\n" +
                    "       p.name as DC_DESCR50,\n" +
                    "       d.code as DEPTID,\n" +
                    "       d.name as DC_DESCR50_2,\n" +
                    "       to_char(k2.hiredate,'yyyy-mm-dd') as DC_CO_ENTRY_DT,\n" +
                    "       '' as TERMINATION_DT,\n" +
                    "       f.nwq as DC_BZGW_NWSERV,\n" +
                    "       ft.rzdqbmrq as DEPT_ENTRY_DT,\n" +
                    "       ft.rdqgwrq as POSITION_ENTRY_DT,\n" +
                    "       ft.yglx as EMPL_CLASS,\n" +
                    "       ft.ygzj as DC_GRADE_CD,\n" +
                    "       ft.xlms as JOB_FUNCTION,\n" +
                    "       ft.zxms as DC_DISCRIPTION,\n" +
                    "       to_char(k2.active_date,'yyyy-mm-dd') as EFFDT\n" +
                    " from eteams.hrm_extra_organization k \n" +
                    " left join (select * from eteams.department where type='department') d on d.id = k.department_id\n" +
                    " left join eteams.position p on p.id = k.position_id\n" +
                    " inner join eteams.employee k2 on k2.id = k.employee_id\n" +
                    " left join eteams.ft_1104523695920578614 f on f.form_data_id = k2.formdata\n" +
                    " left join hr_userinfo h2 on h2.\"USER\" = k2.id\n" +
                    " left join ft_1104525443890176000 ft on ft.form_data_id = h2.form_data\n" +
                    " where k.status = 1 \n" +
                    " and k.delete_type=0 \n" +
                    " and k2.delete_type=0  \n" +
                    " and k.delete_type=0 " +
                    " and k.tenant_key= ? " +
                    " and k2.tenant_key= ?";

            log.error("queryEmployeeBaseList--dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(tenant_key);
            paramList.add(tenant_key);

            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            recordList = databaseUtils.getDataSourceList(result);
            for(int i=0;i<recordList.size();i++){
                Map<String, Object> recordMap = recordList.get(i);
                recordMap.putAll(companyMap);

                String jobFunction = String.valueOf(recordMap.get("job_function"));
                log.error("jobFunction:"+jobFunction);

                if(StringUtils.isNotBlank(jobFunction)){
                    if(sequenceMarkMap.containsKey(jobFunction)){
                        String xlms = sequenceMarkMap.get(jobFunction);
                        log.error("xlms:"+xlms);
                        recordMap.put("descrshort",xlms);
                    }else{
                        recordMap.put("descrshort","");
                    }
                    if(sequenceCodeMap.containsKey(jobFunction)){
                        String xl = sequenceCodeMap.get(jobFunction);
                        log.error("xl:"+xl);
                        recordMap.put("job_function",xl);
                    }
                }else{
                    recordMap.put("descrshort","");
                }
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("queryFromTableField:e:" + e);
        }
        return recordList;
    }


    /***
     *
     * @param tenant_key
     * @return
     */
//    public List<Map<String, Object>> queryEmployeeCustomList(String tenant_key){
//        String groupId = "weaver-ebuilder-form-service";
//        String sourceType = "LOGIC";
//        List<Map<String, Object>> recordList = new ArrayList<Map<String, Object>>();
//        try{
//
//            Map<String,Object> companyMap = queryCompanyData(tenant_key);
//
//            String dataSql =" select k.id as EMPLID," +
//                    "        '1' as EMPL_RCD," +
//                    "        k.job_num as DC_EMPL_NO," +
//                    "        k.personnel_status as DC_EMPL_STATUS," +
//                    "        '1' as DC_HR_STATUS," +
//                    "        d.code as DEPTID," +
//                    "        d.name as DC_DESCR50_2,\n" +
//                    "        k.hiredate as DC_CO_ENTRY_DT," +
//                    "        '' as TERMINATION_DT," +
//                    "        'Y' as DC_BZGW_NWSERV," +
//                    "        k.active_date as EFFDT," +
//                    "        g.name as DC_GRADE_CD\n" +
//                    " from eteams.employee k\n" +
//                    " left join (select * from eteams.department where type='department' ) d on d.id = k.department\n" +
//                    " left join eteams.position p on p.id = k.position\n" +
//                    " left join eteams.grade g on g.id = k.grade" +
//                    " where k.personnel_status = 3 " +
//                    " and k.delete_type=0 " +
//                    " and k.tenant_key= ? ";
//
//            log.error("queryFromTableField--dataSql:" + dataSql);
//            List<String> paramList = new ArrayList<>(100);
//            paramList.add(tenant_key);
//
//            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
//            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
//            recordList = databaseUtils.getDataSourceList(result);
//            for(int i=0;i<recordList.size();i++){
//                Map<String, Object> recordMap = recordList.get(i);
//                recordMap.putAll(companyMap);
//            }
//        }catch (Exception e){
//            e.printStackTrace();
//            log.error("queryFromTableField:e:" + e);
//        }
//        return recordList;
//    }

    /**
     *
     * @param tenant_key
     * @param formName
     * @param dataKey
     * @return
     */
    public Map<String, Object> queryFromTableField(String tenant_key,String formName,String dataKey){
        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";
        Map<String, Object> fieldMap = new HashMap<String, Object>();
        try{
            // 'dcsl','sfdccg','dcr','dcrq','dcsj'
            String dataSql =" select id,form_id,title,data_key " +
                    " from form_field " +
                    " where form_id in(select form_id from form_table where table_name=? and delete_type=0 and tenant_key=?) \n" +
                    " and data_key in("+dataKey+")\n" +
                    " and sub_form_id is null " +
                    " and tenant_key=? \n" +
                    " and delete_type=0" ;

            log.error("queryFromTableField--dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(formName);
            paramList.add(tenant_key);
            paramList.add(tenant_key);

            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("queryFromTableField:"+recordList.size());
            for(Map<String,Object> recordMap : recordList ) {
                String data_key = String.valueOf(recordMap.get("data_key"));
                String id = String.valueOf(recordMap.get("id"));
                fieldMap.put(data_key,id);
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("queryFromTableField:e:" + e);
        }
        return fieldMap;
    }


    /***
     *
     * @param tenant_key
     * @param formName
     * @return
     */
    public String queryTableFormId(String tenant_key,String formName){
        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";
        String form_id = "";

        try{
            String dataSql =" select id from ebdf_obj where table_name=? and delete_type=0 and tenant_key=?" ;
            log.error("dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(formName);
            paramList.add(tenant_key);

            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("queryTableFormId:"+recordList.size());
            if(recordList.size()>0){
                Map<String, Object> recordMap = recordList.get(0);
                form_id = String.valueOf(recordMap.get("id"));
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("queryTableFormId:e:" + e);
        }
        return form_id;
    }

    /***
     *
     * @param tenant_key
     * @return
     */
    public String queryExportTxtTimesByDay(String tenant_key){
        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";
        String times = "";

        SimpleDateFormat sdfDate = new SimpleDateFormat("yyyy-MM-dd");
        String nowDate = sdfDate.format(new Date());

        try{
            String dataSql =" select lpad((count(1)+1),2,'0') as cou from uf_employee_imp where dcrq= ? and delete_type=0 and tenant_key=? " ;
            log.error("dataSql:" + dataSql);

            List<String> paramList = new ArrayList<>(100);
            paramList.add(nowDate);
            paramList.add(tenant_key);
            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("queryTableFormId:"+recordList.size());
            if(recordList.size()>0){
                Map<String, Object> recordMap = recordList.get(0);
                times = String.valueOf(recordMap.get("cou"));
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("queryTableFormId:e:" + e);
        }
        return times;
    }


    public String queryMaxDateByExport(String tenant_key){
        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";
        String dcsj = "";

        try{
            String dataSql =" select max(dcrq||' '||dcsj) as dcsj from uf_employee_imp where delete_type=0 and tenant_key=? " ;
            log.error("dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(tenant_key);
            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("queryTableFormId:"+recordList.size());
            if(recordList.size()>0){
                Map<String, Object> recordMap = recordList.get(0);
                dcsj = String.valueOf(recordMap.get("dcsj"));
            }

            log.error("dcsj:"+dcsj);
        }catch (Exception e){
            e.printStackTrace();
            log.error("queryTableFormId:e:" + e);
        }
        return dcsj;
    }



    public Map<String,String> queryHrmSequenceCode(String tenant_key){
        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";
        Map<String,String> dataMap = new HashMap<String,String>();
        try{
            String dataSql =" select id,xl from uf_xl where delete_type=0 and tenant_key=? " ;
            log.error("dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(tenant_key);
            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("recordList:"+recordList.size());
            for(Map<String,Object> recordMap : recordList ) {
                String xl = String.valueOf(recordMap.get("xl"));
                String id = String.valueOf(recordMap.get("id"));
                dataMap.put(id,xl);
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("e:" + e);
        }
        return dataMap;
    }


    public Map<String,String> queryHrmSequenceReamrk(String tenant_key){
        String groupId = "weaver-ebuilder-form-service";
        String sourceType = "LOGIC";
        Map<String,String> dataMap = new HashMap<String,String>();
        try{
            String dataSql =" select id,xlms from uf_xl where delete_type=0 and tenant_key=? " ;
            log.error("dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(tenant_key);
            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            List<Map<String, Object>> recordList = databaseUtils.getDataSourceList(result);
            log.error("recordList:"+recordList.size());
            for(Map<String,Object> recordMap : recordList ) {
                String id = String.valueOf(recordMap.get("id"));
                String xlms = String.valueOf(recordMap.get("xlms"));
                dataMap.put(id,xlms);
            }
        }catch (Exception e){
            e.printStackTrace();
            log.error("e:" + e);
        }
        return dataMap;
    }


    public List<Map<String, Object>> queryUser(String tenant_key){
        String groupId = "weaver-hr-service";
        String sourceType = "LOGIC";
        List<Map<String, Object>> recordList = new ArrayList<Map<String, Object>>();
        try{
            String dataSql =" select user from hr_userinfo where \"USER\" is not null and delete_type=0 and tenant_key=? " ;
            log.error("dataSql:" + dataSql);
            List<String> paramList = new ArrayList<>(100);
            paramList.add(tenant_key);
            List<SqlParamEntity> sqlParamList = databaseUtils.querySqlParamEntity(paramList);
            Map<String, Object> result = databaseUtils.executeForQuery(sourceType, groupId, dataSql, sqlParamList);
            recordList = databaseUtils.getDataSourceList(result);
        }catch (Exception e){
            e.printStackTrace();
            log.error("e:" + e);
        }
        return recordList;
    }


    public List<Map<String, Object>> queryUserData(String tenant_key){
        String groupId = "weaver-hr-service";
        String sourceType = "LOGIC";
        List<Map<String, Object>> recordList = new ArrayList<Map<String, Object>>();
        try{
            String dataSql =" select k.id as EMPLID,\n" +
                    "                                    '1' as EMPL_RCD,\n" +
                    "                                    k.job_num as DC_EMPL_NO,\n" +
                    "                                    k.personnel_status as DC_EMPL_STATUS,\n" +
                    "                                    '1' as DC_HR_STATUS,\n" +
                    "                                    p.code as POSITION_NBR,\n" +
                    "                                    p.name as DC_DESCR50,\n" +
                    "                                    d.code as DEPTID,\n" +
                    "                                    d.name as DC_DESCR50_2,\n" +
                    "                                    to_char(k.hiredate,'yyyy-mm-dd') as DC_CO_ENTRY_DT,\n" +
                    "                                    '' as TERMINATION_DT,\n" +
                    "                                    f.nwq as DC_BZGW_NWSERV,\n" +
                    "                                    ft.rzdqbmrq as DEPT_ENTRY_DT,\n" +
                    "                                    ft.rdqgwrq as POSITION_ENTRY_DT,\n" +
                    "                                    ft.yglx as EMPL_CLASS,\n" +
                    "                                    ft.ygzj as DC_GRADE_CD,\n" +
                    "                                    ft.xlms  as JOB_FUNCTION,\n" +
                    "                                    ft.zxms as DC_DISCRIPTION,\n" +
                    "                                    to_char(k.active_date,'yyyy-mm-dd') as EFFDT\n" +
                    "                             from eteams.employee k\n" +
                    "                             left join (select * from eteams.department where type='department' ) d on d.id = k.department\n" +
                    "                             left join eteams.position p on p.id = k.position\n" +
                    "                             left join eteams.ft_1104523695920578614 f on f.form_data_id = k.formdata\n" +
                    "                             left join hr_userinfo h2 on h2.\"USER\" = k.id\n" +
                    "                             left join ft_1104525443890176000 ft on ft.form_data_id = h2.form_data\n" +
                    "                             where k.personnel_status = 3 \n" +
                    "                             and k.delete_type=0 \n" +
                    "                             and k.username like '%陈%'" +
                    "" ;
            log.error("dataSql:" + dataSql);
            Map<String, Object> result = databaseUtils.execute(sourceType, groupId, dataSql);
            recordList = databaseUtils.getDataSourceList(result);
        }catch (Exception e){
            e.printStackTrace();
            log.error("e:" + e);
        }
        return recordList;
    }





}
