package com.weaver.seconddev.prod.service.impl;

import com.weaver.ebuilder.form.client.entity.data.*;
import com.weaver.ebuilder.form.client.service.data.RemoteSimpleDataService;
import com.weaver.framework.rpc.annotation.RpcReference;
import com.weaver.seconddev.prod.constant.Constants;
import com.weaver.seconddev.prod.dao.EmployeeExportTxtDao;
import com.weaver.seconddev.prod.service.EmployeeExportTxtService;
import com.weaver.teams.domain.user.SimpleEmployee;
import com.weaver.teams.security.context.UserContext;
import org.apache.commons.compress.utils.Lists;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * author:zhangmingqiang
 * date:2025/03/05
 */
@Service
public class EmployeeExportTxtServiceImpl implements EmployeeExportTxtService {

    private final Logger log = LoggerFactory.getLogger(EmployeeExportTxtServiceImpl.class);

    @Autowired
    private EmployeeExportTxtDao employeeExportTxtDao;

    @RpcReference(group="ebuilderform")
    private RemoteSimpleDataService remoteSimpleDataService;

    @Override
    public List<Map<String, Object>> queryEmployeeBase(String tenant_key) {

        List<Map<String,Object>> employyeeList = employeeExportTxtDao.queryEmployeeBaseList(Constants.TENANT_KEY,"0");
        return employyeeList;
    }

    @Override
    public List<Map<String, Object>> queryEmployeeCustom(String tenant_key) {
        List<Map<String,Object>> employyeeList = employeeExportTxtDao.queryEmployeeBaseList(Constants.TENANT_KEY,"0");
        return employyeeList;
    }

    @Override
    public String queryEmployeeExpTxt(String tenant_key,String type) {
        List<String>  fieldList = getEmployeeExportFieldList();
        String message = "";
        List<Map<String,Object>> employyeeList = employeeExportTxtDao.queryEmployeeBaseList(Constants.TENANT_KEY,type);
        for(int i=0;i<employyeeList.size();i++){
            Map<String,Object> employeeMap = employyeeList.get(i);

            int n = 0;
            for(String key : fieldList){
                if(n == 0 || n == (fieldList.size())){
                    message += employeeMap.get(key.toLowerCase());
                }else{
                    message += StringUtils.isBlank(message) ? employeeMap.get(key.toLowerCase()) : "|" + employeeMap.get(key.toLowerCase());
                }
                n++;
            }
            message+=System.lineSeparator() ;
        }

        List<Map<String,Object>> empExtraList = employeeExportTxtDao.queryEmployeeExtraList(Constants.TENANT_KEY);
        for(int i=0;i<empExtraList.size();i++){
            Map<String,Object> employeeMap = empExtraList.get(i);
            int n = 0;
            for(String key : fieldList){
                if(n == 0 || n == (fieldList.size())){
                    message += employeeMap.get(key.toLowerCase());
                }else{
                    message += StringUtils.isBlank(message) ? employeeMap.get(key.toLowerCase()) : "|" + employeeMap.get(key.toLowerCase());
                }
                n++;
            }
            message+=System.lineSeparator() ;
        }

//        log.error("message:"+message);
        SimpleEmployee simpleEmployee = UserContext.getCurrentUser();

        SimpleDateFormat sdfDate = new SimpleDateFormat("yyyy-MM-dd");
        SimpleDateFormat sdfTime = new SimpleDateFormat("HH:mm:ss");

        String formName = "uf_employee_imp";
        String dataKey = "'dcsl','sfdccg','dcr','dcrq','dcsj','dclx'";
        String formId = employeeExportTxtDao.queryTableFormId(Constants.TENANT_KEY,formName);
        log.error("formId:"+formId);
        Map<String,Object> fieldMap = employeeExportTxtDao.queryFromTableField(Constants.TENANT_KEY,formName,dataKey);
        List<EBDataReqDto> insertEbDataReqDtoList = Lists.newArrayList();
        EBDataReqDto ebDataReqDto = new EBDataReqDto();
        List<EBDataReqDetailDto> mainData = Lists.newArrayList();

        log.error("dcsl:"+String.valueOf(fieldMap.get("dcsl")));
        log.error("sfdccg:"+String.valueOf(fieldMap.get("sfdccg")));
        log.error("dcr:"+String.valueOf(fieldMap.get("dcr")));
        log.error("dcrq:"+String.valueOf(fieldMap.get("dcrq")));
        log.error("dcsj:"+String.valueOf(fieldMap.get("dcsj")));

        String dclx = "0";
        if("1".equals(type)){
            dclx = "1";
        }else{
            dclx = "0";
        }
        mainData.add(new EBDataReqDetailDto(String.valueOf(fieldMap.get("dcsl")), String.valueOf(employyeeList.size())));
        mainData.add(new EBDataReqDetailDto(String.valueOf(fieldMap.get("sfdccg")), employyeeList.size() >0 ? "1" : "0" ));
        mainData.add(new EBDataReqDetailDto(String.valueOf(fieldMap.get("dcr")), String.valueOf(simpleEmployee.getEmployeeId())));
        mainData.add(new EBDataReqDetailDto(String.valueOf(fieldMap.get("dcrq")), sdfDate.format(new Date())));
        mainData.add(new EBDataReqDetailDto(String.valueOf(fieldMap.get("dcsj")), sdfTime.format(new Date())));
        mainData.add(new EBDataReqDetailDto(String.valueOf(fieldMap.get("dclx")), dclx));

        ebDataReqDto.setMainDatas(mainData);
        insertEbDataReqDtoList.add(ebDataReqDto);

        log.error("getEmployeeId:"+String.valueOf(simpleEmployee.getEmployeeId()));

        saveModeData(formId,String.valueOf(simpleEmployee.getEmployeeId()),tenant_key,insertEbDataReqDtoList);

        return message;
    }

    /***
     *
     * @param objId
     * @param operator
     * @param tenant_key
     * @param datas
     */
    public void saveModeData(String objId,String operator,String tenant_key,List<EBDataReqDto> datas){

        log.error("saveModeData-objid:"+objId);
        log.error("saveModeData-operator:"+operator);
        log.error("saveModeData-tenant_key:"+tenant_key);
        log.error("saveModeData-datas:"+datas.size());
        try{
            EBDataChangeReqDto ebDataChangeReqDto = new EBDataChangeReqDto();
            // 构建基础参数; objId 表单id, operator 操作人, tenantKey 租户
            ebDataChangeReqDto.setHeader(new EBDataReqHeader(objId, operator,tenant_key));

            ebDataChangeReqDto.setDatas(datas);
            EBDataChangeResult insertEbDataChangeResult = remoteSimpleDataService.saveFormData(ebDataChangeReqDto);
            log.error("insertEbDataChangeResult:"+insertEbDataChangeResult.getMessage());
            log.error("insertEbDataChangeResult:"+insertEbDataChangeResult.toString());
            log.error("insertEbDataChangeResult:"+insertEbDataChangeResult.getStatus());
        }catch (Exception e){
            log.error("e:"+e);
        }

    }



    public List<String> getEmployeeExportFieldList() {

        List<String> fieldList = new ArrayList<String>();
        /**
         * 员工ID
         */
        fieldList.add("EMPLID");
        /**
         * 员工记录
         */
        fieldList.add("EMPL_RCD");
        /**
         * 员工工号
         */
        fieldList.add("DC_EMPL_NO");
        /**
         * 人员状态
         */
        fieldList.add("DC_EMPL_STATUS");
        /**
         * 在职状态
         */
        fieldList.add("DC_HR_STATUS");
        /**
         * 岗位编码
         */
        fieldList.add("POSITION_NBR");
        /***
         * 岗位名称
         */
        fieldList.add("DC_DESCR50");
        /***
         * 公司编码
         */
        fieldList.add("COMPANY");
        /**
         * 公司名称
         */
        fieldList.add("DESCR");
        /***
         * 部门编码
         */
        fieldList.add("DEPTID");
        /***
         * 部门名称
         */
        fieldList.add("DC_DESCR50_2");
        /**
         * 入职日期
         */
        fieldList.add("DC_CO_ENTRY_DT");
        /**
         * 离职日期
         */
        fieldList.add("TERMINATION_DT");
        /**
         * 内外勤
         */
        fieldList.add("DC_BZGW_NWSERV");
        /**
         * 入当前部门日期
         */
        fieldList.add("DEPT_ENTRY_DT");
        /**
         * 任当前岗位日期
         */
        fieldList.add("POSITION_ENTRY_DT");
        /***
         * 用工类型
         */
        fieldList.add("EMPL_CLASS");
        /***
         * 员工职级
         */
        fieldList.add("DC_GRADE_CD");
        /***
         * 序列
         */
        fieldList.add("JOB_FUNCTION");
        /**
         * 序列描述
         */
        fieldList.add("DESCRSHORT");
        /***
         * 职衔描述
         */
        fieldList.add("DC_DISCRIPTION");
        /**
         * 生效日期
         */
        fieldList.add("EFFDT");

        return fieldList;
    }

}
